@@ -1,20 +1,21 @@
 
 #define HOST_CPU "powerpc"
 #define HOST_VENDOR "ibm"
-#define HOST_OS "aix4.2.1.0"
+#define HOST_OS "aix4.3.1.0"
 #define HOST_OS_NAME "aix4"
-#define HOST_OS_VERSION "4.2.1.0"
-#define HOST_ARCH "002025934C00"
-#define HOST_NAME "quechua"
+#define HOST_OS_VERSION "4.3.1.0"
+#define HOST_ARCH "000266964C00"
+#define HOST_NAME "sp-00"
 #define USER_NAME "ezk"
-#define CONFIG_DATE "Tue Jul  4 17:06:01 EDT 2000"
+#define CONFIG_DATE "Wed Sep  8 13:43:08 EDT 1999"
 #define PACKAGE "am-utils"
-#define VERSION "6.0.4s6"
+#define VERSION "6.0.1"
 #define PACKAGE "am-utils"
-#define VERSION "6.0.4s6"
+#define VERSION "6.0.1"
 #define DEBUG 1
 #define _ALL_SOURCE 1
-#define HOST_HEADER_VERSION "4.2.1.0"
+#define HOST_HEADER_VERSION "4.3.1.0"
+#define YYTEXT_POINTER 1
 #define HAVE_LIBRPCSVC 1
 #define HAVE_ALLOCA 1
 #define STDC_HEADERS 1
@@ -46,7 +47,6 @@
 #define HAVE_RMDIR 1
 #define HAVE_SELECT 1
 #define HAVE_SETEUID 1
-#define HAVE_SETITIMER 1
 #define HAVE_SETSID 1
 #define HAVE_SIGACTION 1
 #define HAVE_SIGNAL 1
@@ -67,7 +67,6 @@
 #define HAVE_UVMOUNT 1
 #define HAVE_VFORK 1
 #define HAVE_VMOUNT 1
-#define HAVE_VSNPRINTF 1
 #define HAVE_WAIT3 1
 #define HAVE_WAITPID 1
 #define HAVE_CLNT_SPERRNO 1
@@ -154,7 +153,8 @@
 #define HAVE_VARARGS_H 1
 #define HAVE_UNISTD_H 1
 #define TIME_WITH_SYS_TIME 1
-#define AMU_NFS_PROTOCOL_HEADER "../conf/nfs_prot/nfs_prot_aix4_2.h"
+#define HAVE_ST_RDEV 1
+#define AMU_NFS_PROTOCOL_HEADER "../conf/nfs_prot/nfs_prot_aix4_3.h"
 #define HAVE_STRUCT_NFS_ARGS 1
 #define nfs_args_t struct aix42_nfs_args
 #define NFS_FH_FIELD fh
@@ -164,9 +164,9 @@
 #define RETSIGTYPE void
 #define MTYPE_TYPE int
 #define MTYPE_PRINTF_TYPE "%d"
-#define YP_ORDER_OUTORDER_TYPE int
+#define YP_ORDER_OUTORDER_TYPE unsigned long
 #define RECVFROM_FROMLEN_TYPE size_t
-#define AUTH_CREATE_GIDLIST_TYPE int
+#define AUTH_CREATE_GIDLIST_TYPE gid_t
 #define SVC_IN_ARG_TYPE caddr_t
 #define XDRPROC_T_TYPE xdrproc_t
 #define WORDS_BIGENDIAN 1
@@ -175,20 +175,22 @@
 #define HAVE_EXTERN_CLNT_SPCREATEERROR 1
 #define HAVE_EXTERN_CLNT_SPERRNO 1
 #define HAVE_EXTERN_FREE 1
+#define HAVE_EXTERN_GETDOMAINNAME 1
 #define HAVE_EXTERN_GETDTABLESIZE 1
 #define HAVE_EXTERN_GETHOSTNAME 1
 #define HAVE_EXTERN_GETLOGIN 1
 #define HAVE_EXTERN_GETPAGESIZE 1
 #define HAVE_EXTERN_GETWD 1
+#define HAVE_EXTERN_INNETGR 1
 #define HAVE_EXTERN_MKSTEMP 1
 #define HAVE_EXTERN_SBRK 1
-#define HAVE_EXTERN_SETITIMER 1
 #define HAVE_EXTERN_STRCASECMP 1
 #define HAVE_EXTERN_STRDUP 1
 #define HAVE_EXTERN_STRSTR 1
 #define HAVE_EXTERN_UALARM 1
 #define HAVE_EXTERN_USLEEP 1
 #define HAVE_EXTERN_WAIT3 1
+#define HAVE_EXTERN_XDR_OPAQUE_AUTH 1
 #define HAVE_LONG_FILE_NAMES 1
 #define HAVE_FIELD_STRUCT_FHSTATUS_FHS_FH 1
 #define HAVE_FIELD_NFS_ARGS_T_ACDIRMIN 1
@@ -196,31 +198,37 @@
 #define HAVE_FIELD_NFS_ARGS_T_PROTO 1
 #define HAVE_FIELD_STRUCT_IFREQ_IFR_ADDR 1
 #define HAVE_FIELD_STRUCT_SOCKADDR_SA_LEN 1
+#define HAVE_FGETS 1
 #define HAVE_MAP_FILE 1
+#define HAVE_DBM_OPEN 1
 #define HAVE_MAP_NDBM 1
+#define HAVE_YP_GET_DEFAULT_DOMAIN 1
 #define HAVE_MAP_NIS 1
+#define HAVE_GETPWNAM 1
 #define HAVE_MAP_PASSWD 1
+#define HAVE_OPENDIR 1
 #define HAVE_MAP_UNION 1
 #define HAVE_FS_CDFS 1
 #define HAVE_FS_NFS 1
 #define HAVE_FS_NFS3 1
 #define HAVE_FS_UFS 1
-#define HAVE_AMU_FS_AUTO 1
-#define HAVE_AMU_FS_DIRECT 1
-#define HAVE_AMU_FS_TOPLVL 1
-#define HAVE_AMU_FS_ERROR 1
-#define HAVE_AMU_FS_INHERIT 1
-#define HAVE_AMU_FS_PROGRAM 1
-#define HAVE_AMU_FS_LINK 1
-#define HAVE_AMU_FS_LINKX 1
-#define HAVE_AMU_FS_HOST 1
-#define HAVE_AMU_FS_NFSX 1
-#define HAVE_AMU_FS_NFSL 1
-#define HAVE_AMU_FS_UNION 1
+#define HAVE_AM_FS_AUTO 1
+#define HAVE_AM_FS_DIRECT 1
+#define HAVE_AM_FS_TOPLVL 1
+#define HAVE_AM_FS_ERROR 1
+#define HAVE_AM_FS_INHERIT 1
+#define HAVE_AM_FS_PROGRAM 1
+#define HAVE_AM_FS_LINK 1
+#define HAVE_AM_FS_LINKX 1
+#define HAVE_AM_FS_HOST 1
+#define HAVE_AM_FS_NFSX 1
+#define HAVE_AM_FS_NFSL 1
+#define HAVE_AM_FS_UNION 1
 #define MOUNT_TYPE_NFS MNT_NFS
 #define MOUNT_TYPE_NFS3 MNT_NFS3
 #define MOUNT_TYPE_UFS MNT_JFS
 #define MOUNT_TYPE_CDFS MNT_CDROM
+#define MOUNT_TYPE_CACHEFS MNT_CACHEFS
 #define MNTTAB_TYPE_NFS "nfs"
 #define MNTTAB_TYPE_NFS3 "nfs3"
 #define MNTTAB_TYPE_UFS "ufs"
@@ -263,3 +271,4 @@
 #define MNT2_NFS_OPT_TIMEO 0x8
 #define MNT2_NFS_OPT_WSIZE 0x2
 #define HIDE_MOUNT_TYPE "nfs"
+#define HAVE_MNTCTL 1
